To do list
----------

1. (package) Expand automated testing
2. (package) Expand documentation A LOT
3. (rapidtide) Finish implementing the --tmask option
4. (tidepool) Implement ASPECTS averaging
7. (rapidtide) Implement a dispersive delay model

Implement new argument parsing:
rapidtide/experimental/highresmotion
rapidtide/experimental/harmonogram
rapidtide/workflows/happy.py
rapidtide/workflows/rapidtide2x_parser.py
rapidtide/workflows/linfit.py
rapidtide/scripts/happy2std
rapidtide/scripts/applydlfilter
rapidtide/scripts/atlastool
rapidtide/scripts/spatialfit
rapidtide/scripts/showstxcorr
rapidtide/scripts/pixelcomp
rapidtide/scripts/histtc
rapidtide/scripts/plethquality
rapidtide/scripts/filttc
rapidtide/scripts/ccorrica
rapidtide/scripts/resamplenifti
rapidtide/scripts/threeD
rapidtide/scripts/resamp1tc
rapidtide/scripts/showxcorr
rapidtide/scripts/atlasaverage
rapidtide/scripts/showxcorrx
rapidtide/scripts/simdata
rapidtide/scripts/rapidtide2std


